@@ -14,15 +14,17 @@ describe 'aodh::wsgi::apache' do
         :path                        => '/',
         :servername                  => facts[:fqdn],
         :ssl                         => true,
-        :threads                     => facts[:os_workers],
+        :threads                     => 1,
         :user                        => 'aodh',
-        :workers                     => 1,
+        :workers                     => facts[:os_workers],
         :wsgi_daemon_process         => 'aodh',
         :wsgi_process_group          => 'aodh',
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'app',
         :wsgi_script_source          => platform_params[:wsgi_script_source],
         :custom_wsgi_process_options => {},
+        :access_log_file             => false,
+        :access_log_format           => false,
       )}
     end
 
@@ -38,6 +40,9 @@ describe 'aodh::wsgi::apache' do
           :custom_wsgi_process_options => {
             'python_path' => '/my/python/path',
           },
+          :access_log_file             => '/var/log/httpd/access_log',
+          :access_log_format           => 'some format',
+          :error_log_file              => '/var/log/httpd/error_log'
         }
       end
       it { is_expected.to contain_class('aodh::params') }
@@ -51,7 +56,7 @@ describe 'aodh::wsgi::apache' do
         :path                      => '/',
         :servername                => 'dummy.host',
         :ssl                       => false,
-        :threads                   => facts[:os_workers],
+        :threads                   => 1,
         :user                      => 'aodh',
         :workers                   => 37,
         :wsgi_daemon_process       => 'aodh',
@@ -63,6 +68,9 @@ describe 'aodh::wsgi::apache' do
         :custom_wsgi_process_options => {
           'python_path' => '/my/python/path',
         },
+        :access_log_file           => '/var/log/httpd/access_log',
+        :access_log_format         => 'some format',
+        :error_log_file            => '/var/log/httpd/error_log'
       )}
     end
   end
